interface CacheItem {
    key: string;
    value: unknown;
    expires: number;
}
interface CacheTable {
    [key: string]: CacheItem;
}
interface ICredential {
    session?: string;
    csrf?: string;
}
interface LeetCodeGraphQLQuery {
    operationName: string;
    variables: {
        [key: string]: unknown;
    };
    query: string;
}

declare class Credential implements ICredential {
    session?: string;
    csrf?: string;
    constructor(data?: ICredential);
    init(session?: string): Promise<this>;
}

declare class Cache {
    private _table;
    get(key: string): unknown;
    set(key: string, value: unknown, expires?: number): void;
    remove(key: string): void;
    clear(): void;
    load(json: string): void;
}
declare const cache: Cache;
declare const caches: {
    [key: string]: Cache;
};

declare class LeetCode {
    private credential;
    private cache;
    constructor(credential?: Credential | null, cache?: Cache | null);
    get_user(username: string): Promise<any>;
    get_recent_submissions(username: string, limit?: number): Promise<unknown[]>;
    get_submissions(limit?: number, offset?: number): Promise<unknown[]>;
    graphql(query: LeetCodeGraphQLQuery): Promise<any>;
}

export { Cache, CacheItem, CacheTable, Credential, ICredential, LeetCode, LeetCodeGraphQLQuery, cache, caches, LeetCode as default };
